@@ -1,16 +1,14 @@
 from __future__ import absolute_import, print_function, division
 
 import numpy as np
-try:
-    from astropy.convolution import convolve as astropy_convolve, Gaussian2DKernel, Box2DKernel
-    make_kernel = None
-except ImportError:
-    from astropy.nddata import convolve as astropy_convolve, make_kernel
+
+from astropy.convolution import (convolve as astropy_convolve,
+                                 Gaussian2DKernel, Box2DKernel)
 
 
 def convolve(image, smooth=3, kernel='gauss'):
 
-    if smooth is None and kernel in ['box', 'gauss']:
+    if smooth is None and isinstance(kernel, str) and kernel in ['box', 'gauss']:
         return image
 
     if smooth is not None and not np.isscalar(smooth):
@@ -24,16 +22,13 @@ def convolve(image, smooth=3, kernel='gauss'):
     image_fixed = np.array(image, dtype=float, copy=True)
     image_fixed[np.isinf(image)] = np.nan
 
-    if kernel == 'gauss':
-        if make_kernel is None:
+    if isinstance(kernel, str):
+        if kernel == 'gauss':
             kernel = Gaussian2DKernel(smooth, x_size=smooth * 5, y_size=smooth * 5)
-        else:
-            kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'gaussian')
-    elif kernel == 'box':
-        if make_kernel is None:
+        elif kernel == 'box':
             kernel = Box2DKernel(smooth, x_size=smooth * 5, y_size=smooth * 5)
         else:
-            kernel = make_kernel((smooth * 5, smooth * 5), smooth, 'boxcar')
+            raise ValueError("Unknown kernel: {0}".format(kernel))
     else:
         kernel = kernel
 
