@@ -2,6 +2,15 @@ from __future__ import absolute_import, print_function, division
 
 from astropy import log
 
+PLATE_CAREE_ERROR = """
+Projection is Plate Caree (-CAR) and CRVALy is not zero. This can be interpreted
+either according to Wells (1981) or Calabretta (2002). The former defines the
+projection as rectilinear regardless of the value of CRVALy, whereas the latter
+defines the projection as rectilinear only when CRVALy is zero. You will need to
+specify the convention to assume by setting either convention='wells' or
+convention='calabretta' when initializing the FITSFigure instance.
+""".strip()
+
 
 def check(header, convention=None, dimensions=[0, 1]):
 
@@ -24,13 +33,10 @@ def check(header, convention=None, dimensions=[0, 1]):
     if header['CTYPE%i' % ix][4:] == '-CAR' and header['CTYPE%i' % iy][4:] == '-CAR':
 
         if header['CTYPE%i' % ix][:4] == 'DEC-' or header['CTYPE%i' % ix][1:4] == 'LAT':
-            ilon = iy
             ilat = ix
         elif header['CTYPE%i' % iy][:4] == 'DEC-' or header['CTYPE%i' % iy][1:4] == 'LAT':
-            ilon = ix
             ilat = iy
         else:
-            ilon = None
             ilat = None
 
         if ilat is not None and header['CRVAL%i' % ilat] != 0:
@@ -46,15 +52,7 @@ def check(header, convention=None, dimensions=[0, 1]):
                 crpix = crpix - crval / cdelt
                 header['CRPIX%i' % ilat] = crpix
                 header['CRVAL%i' % ilat] = 0.
-
             else:
-                raise Exception('''WARNING: projection is Plate Caree (-CAR) and
-                CRVALy is not zero. This can be interpreted either according to
-                Wells (1981) or Calabretta (2002). The former defines the
-                projection as rectilinear regardless of the value of CRVALy,
-                whereas the latter defines the projection as rectilinear only when
-                CRVALy is zero. You will need to specify the convention to assume
-                by setting either convention='wells' or convention='calabretta'
-                when initializing the FITSFigure instance. ''')
+                raise Exception(PLATE_CAREE_ERROR)
 
     return header
