@@ -1,8 +1,7 @@
-import matplotlib
-matplotlib.use('Agg')
+from __future__ import absolute_import, print_function, division
 
+import pytest
 import numpy as np
-from astropy.tests.helper import pytest
 
 from .. import FITSFigure
 
