@@ -1,13 +1,10 @@
-import matplotlib
-matplotlib.use('Agg')
+from __future__ import absolute_import, print_function, division
 
+import pytest
 import numpy as np
-from astropy.tests.helper import pytest
 
 from .. import FITSFigure
 
-# Test simple contour generation with Numpy example
-
 
 def test_numpy_downsample():
     data = np.arange(256).reshape((16, 16))
