@@ -1,5 +1,7 @@
+from __future__ import absolute_import, print_function, division
+
+import pytest
 import numpy as np
-from astropy.tests.helper import pytest, remote_data
 
 from ..core import FITSFigure
 
@@ -18,18 +20,18 @@ ADATA = np.degrees(np.arctan2(Y, X))
 
 class TestVectors(BaseImageTests):
 
-    @remote_data
-    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, tolerance=1.5)
-    def test_default(self, generate):
+    @pytest.mark.remote_data
+    @pytest.mark.mpl_image_compare(style={}, savefig_kwargs={'adjust_bbox': False}, baseline_dir=baseline_dir, tolerance=1.5)
+    def test_default(self):
         f = FITSFigure(IMAGE, figsize=(4, 4))
         f.show_grayscale()
         f.show_vectors(PDATA, ADATA, color='orange')
-        return f
+        return f._figure
 
-    @remote_data
-    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, tolerance=1.5)
-    def test_step_scale(self, generate):
+    @pytest.mark.remote_data
+    @pytest.mark.mpl_image_compare(style={}, savefig_kwargs={'adjust_bbox': False}, baseline_dir=baseline_dir, tolerance=1.5)
+    def test_step_scale(self):
         f = FITSFigure(IMAGE, figsize=(4, 4))
         f.show_grayscale()
         f.show_vectors(PDATA, ADATA, step=2, scale=0.8, color='orange')
-        return f
+        return f._figure
