@@ -1,8 +1,11 @@
 import os
-import contextlib
-import shutil
-import stat
 import sys
+import stat
+import shutil
+import importlib
+import contextlib
+
+import pytest
 
 from textwrap import dedent
 
@@ -10,12 +13,14 @@ from setuptools import Distribution
 
 from ..setup_helpers import get_package_info, register_commands
 from ..commands import build_ext
-from . import *
 
-IS_APPVEYOR = os.environ.get('APPVEYOR', 'False') == 'True'
+from . import reset_setup_helpers, reset_distutils_log  # noqa
+from . import run_setup, cleanup_import
+
+ASTROPY_HELPERS_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', '..'))
 
 
-def _extension_test_package(tmpdir, request, extension_type='c'):
+def _extension_test_package(tmpdir, request, extension_type='c', include_numpy=False):
     """Creates a simple test package with an extension module."""
 
     test_pkg = tmpdir.mkdir('test_pkg')
@@ -69,9 +74,11 @@ def _extension_test_package(tmpdir, request, extension_type='c'):
     elif extension_type == 'both':
         extensions = ['unit01.c', 'unit02.pyx']
 
+    include_dirs = ['numpy'] if include_numpy else []
+
     extensions_list = [
-        "Extension('apyhtest_eva.{0}', [join('apyhtest_eva', '{1}')])".format(
-            os.path.splitext(extension)[0], extension)
+        "Extension('apyhtest_eva.{0}', [join('apyhtest_eva', '{1}')], include_dirs={2})".format(
+            os.path.splitext(extension)[0], extension, include_dirs)
         for extension in extensions]
 
     test_pkg.join('apyhtest_eva', 'setup_package.py').write(dedent("""\
@@ -82,12 +89,19 @@ def _extension_test_package(tmpdir, request, extension_type='c'):
     """.format(', '.join(extensions_list))))
 
     test_pkg.join('setup.py').write(dedent("""\
+        import sys
         from os.path import join
         from setuptools import setup
+        sys.path.insert(0, r'{astropy_helpers_path}')
         from astropy_helpers.setup_helpers import register_commands
         from astropy_helpers.setup_helpers import get_package_info
         from astropy_helpers.version_helpers import generate_version_py
 
+        if '--no-cython' in sys.argv:
+            from astropy_helpers.commands import build_ext
+            build_ext.should_build_with_cython = lambda *args: False
+            sys.argv.remove('--no-cython')
+
         NAME = 'apyhtest_eva'
         VERSION = '0.1'
         RELEASE = True
@@ -102,7 +116,7 @@ def _extension_test_package(tmpdir, request, extension_type='c'):
             cmdclass=cmdclassd,
             **package_info
         )
-    """))
+    """.format(astropy_helpers_path=ASTROPY_HELPERS_PATH)))
 
     if '' in sys.path:
         sys.path.remove('')
@@ -124,7 +138,10 @@ def extension_test_package(tmpdir, request):
 
 @pytest.fixture
 def c_extension_test_package(tmpdir, request):
-    return _extension_test_package(tmpdir, request, extension_type='c')
+    # Check whether numpy is installed in the test environment
+    has_numpy = bool(importlib.util.find_spec('numpy'))
+    return _extension_test_package(tmpdir, request, extension_type='c',
+                                   include_numpy=has_numpy)
 
 
 @pytest.fixture
@@ -156,7 +173,7 @@ def test_cython_autoextensions(tmpdir):
     assert package_info['ext_modules'][0].name == 'yoda.luke.dagobah'
 
 
-def test_compiler_module(c_extension_test_package):
+def test_compiler_module(capsys, c_extension_test_package):
     """
     Test ensuring that the compiler module is built and installed for packages
     that have extension modules.
@@ -174,6 +191,9 @@ def test_compiler_module(c_extension_test_package):
                    '--install-lib={0}'.format(install_temp),
                    '--record={0}'.format(install_temp.join('record.txt'))])
 
+        stdout, stderr = capsys.readouterr()
+        assert "No git repository present at" in stderr
+
     with install_temp.as_cwd():
         import apyhtest_eva
         # Make sure we imported the apyhtest_eva package from the correct place
@@ -186,7 +206,7 @@ def test_compiler_module(c_extension_test_package):
         assert apyhtest_eva.version.compiler != 'unknown'
 
 
-def test_no_cython_buildext(c_extension_test_package, monkeypatch):
+def test_no_cython_buildext(capsys, c_extension_test_package, monkeypatch):
     """
     Regression test for https://github.com/astropy/astropy-helpers/pull/35
 
@@ -197,13 +217,12 @@ def test_no_cython_buildext(c_extension_test_package, monkeypatch):
 
     test_pkg = c_extension_test_package
 
-    # In order for this test to test the correct code path we need to fool
-    # build_ext into thinking we don't have Cython installed
-    monkeypatch.setattr(build_ext, 'should_build_with_cython',
-                        lambda *args: False)
-
     with test_pkg.as_cwd():
-        run_setup('setup.py', ['build_ext', '--inplace'])
+
+        run_setup('setup.py', ['build_ext', '--inplace', '--no-cython'])
+
+        stdout, stderr = capsys.readouterr()
+        assert "No git repository present at" in stderr
 
     sys.path.insert(0, str(test_pkg))
 
@@ -215,7 +234,7 @@ def test_no_cython_buildext(c_extension_test_package, monkeypatch):
         sys.path.remove(str(test_pkg))
 
 
-def test_missing_cython_c_files(pyx_extension_test_package, monkeypatch):
+def test_missing_cython_c_files(capsys, pyx_extension_test_package, monkeypatch):
     """
     Regression test for https://github.com/astropy/astropy-helpers/pull/181
 
@@ -225,31 +244,26 @@ def test_missing_cython_c_files(pyx_extension_test_package, monkeypatch):
 
     test_pkg = pyx_extension_test_package
 
-    # In order for this test to test the correct code path we need to fool
-    # build_ext into thinking we don't have Cython installed
-    monkeypatch.setattr(build_ext, 'should_build_with_cython',
-                        lambda *args: False)
-
     with test_pkg.as_cwd():
-        with pytest.raises(SystemExit) as exc_info:
-            run_setup('setup.py', ['build_ext', '--inplace'])
 
-    msg = ('Could not find C/C++ file '
-           '{0}.(c/cpp)'.format('apyhtest_eva/unit02'.replace('/', os.sep)))
+        with pytest.raises(SystemExit):
+            run_setup('setup.py', ['build_ext', '--inplace', '--no-cython'])
 
-    assert msg in str(exc_info.value)
+        stdout, stderr = capsys.readouterr()
+        assert "No git repository present at" in stderr
+
+        msg = ('Could not find C/C++ file '
+               '{0}.(c/cpp)'.format('apyhtest_eva/unit02'.replace('/', os.sep)))
+
+        assert msg in stderr
 
 
-@pytest.mark.skipif(IS_APPVEYOR, reason='graphviz cannot currently be installed on AppVeyor')
-@pytest.mark.parametrize('mode', ['cli', 'cli-w', 'direct'])
-def test_build_sphinx(tmpdir, mode):
+@pytest.mark.parametrize('mode', ['cli', 'cli-w', 'deprecated', 'cli-l'])
+def test_build_docs(capsys, tmpdir, mode):
     """
-    Test for build_sphinx
+    Test for build_docs
     """
 
-    import astropy_helpers
-    ah_path = os.path.dirname(astropy_helpers.__file__)
-
     test_pkg = tmpdir.mkdir('test_pkg')
 
     test_pkg.mkdir('mypackage')
@@ -265,31 +279,26 @@ def test_build_sphinx(tmpdir, mode):
             pass
     """))
 
-    docs = test_pkg.mkdir('docs')
-
-    autosummary = docs.mkdir('_templates').mkdir('autosummary')
-
-    autosummary.join('base.rst').write('{% extends "autosummary_core/base.rst" %}')
-    autosummary.join('class.rst').write('{% extends "autosummary_core/class.rst" %}')
-    autosummary.join('module.rst').write('{% extends "autosummary_core/module.rst" %}')
+    test_pkg.mkdir('docs')
 
     docs_dir = test_pkg.join('docs')
-
     docs_dir.join('conf.py').write(dedent("""\
-        import sys
-        sys.path.append("../")
         import warnings
         with warnings.catch_warnings():  # ignore matplotlib warning
             warnings.simplefilter("ignore")
-            from astropy_helpers.sphinx.conf import *
+            from sphinx_astropy.conf import *
         exclude_patterns.append('_templates')
+        suppress_warnings = ['app.add_directive', 'app.add_node', 'app.add_role']
     """))
 
     docs_dir.join('index.rst').write(dedent("""\
         .. automodapi:: mypackage
+           :no-inheritance-diagram:
     """))
 
     test_pkg.join('setup.py').write(dedent("""\
+        import sys
+        sys.path.insert(0, r'{astropy_helpers_path}')
         from os.path import join
         from setuptools import setup, Extension
         from astropy_helpers.setup_helpers import register_commands, get_package_info
@@ -306,22 +315,22 @@ def test_build_sphinx(tmpdir, mode):
             cmdclass=cmdclassd,
             **get_package_info()
         )
-    """))
+    """.format(astropy_helpers_path=ASTROPY_HELPERS_PATH)))
 
     with test_pkg.as_cwd():
-        shutil.copytree(ah_path, 'astropy_helpers')
 
         if mode == 'cli':
-            run_setup('setup.py', ['build_sphinx'])
+            run_setup('setup.py', ['build_docs'])
         elif mode == 'cli-w':
-            run_setup('setup.py', ['build_sphinx', '-w'])
-        elif mode == 'direct':  # to check coverage
-            with docs_dir.as_cwd():
-                from sphinx import main
-                try:
-                    main(['-b html', '-d _build/doctrees', '.', '_build/html'])
-                except SystemExit as exc:
-                    assert exc.code == 0
+            run_setup('setup.py', ['build_docs', '-w'])
+        elif mode == 'cli-l':
+            run_setup('setup.py', ['build_docs', '-l'])
+        elif mode == 'deprecated':
+            run_setup('setup.py', ['build_sphinx'])
+            stdout, stderr = capsys.readouterr()
+            assert 'AstropyDeprecationWarning' in stderr
+
+    assert os.path.exists(docs_dir.join('_build', 'html', 'index.html').strpath)
 
 
 def test_command_hooks(tmpdir, capsys):
@@ -344,8 +353,10 @@ def test_command_hooks(tmpdir, capsys):
     # A simple setup.py for the test package--running register_commands should
     # discover and enable the command hooks
     test_pkg.join('setup.py').write(dedent("""\
+        import sys
         from os.path import join
         from setuptools import setup, Extension
+        sys.path.insert(0, r'{astropy_helpers_path}')
         from astropy_helpers.setup_helpers import register_commands, get_package_info
 
         NAME = '_welltall_'
@@ -359,7 +370,7 @@ def test_command_hooks(tmpdir, capsys):
             version=VERSION,
             cmdclass=cmdclassd
         )
-    """))
+    """.format(astropy_helpers_path=ASTROPY_HELPERS_PATH)))
 
     with test_pkg.as_cwd():
         try:
@@ -376,7 +387,7 @@ def test_command_hooks(tmpdir, capsys):
         Goodbye build!
     """).strip()
 
-    assert want in stdout
+    assert want in stdout.replace('\r\n', '\n').replace('\r', '\n')
 
 
 def test_adjust_compiler(monkeypatch, tmpdir):
@@ -508,3 +519,65 @@ def test_adjust_compiler(monkeypatch, tmpdir):
 
         assert len(log.messages) == 1
         assert 'The C compiler used to compile Python' in log.messages[0]
+
+
+def test_invalid_package_exclusion(tmpdir, capsys):
+
+    module_name = 'foobar'
+    setup_header = dedent("""\
+        import sys
+        from os.path import join
+        from setuptools import setup, Extension
+        sys.path.insert(0, r'{astropy_helpers_path}')
+        from astropy_helpers.setup_helpers import register_commands, \\
+            get_package_info, add_exclude_packages
+
+        NAME = {module_name!r}
+        VERSION = 0.1
+        RELEASE = True
+
+    """.format(module_name=module_name, astropy_helpers_path=ASTROPY_HELPERS_PATH))
+
+    setup_footer = dedent("""\
+        setup(
+            name=NAME,
+            version=VERSION,
+            cmdclass=cmdclassd,
+            **package_info
+        )
+    """)
+
+    # Test error when using add_package_excludes out of order
+    error_commands = dedent("""\
+        cmdclassd = register_commands(NAME, VERSION, RELEASE)
+        package_info = get_package_info()
+        add_exclude_packages(['tests*'])
+
+    """)
+
+    error_pkg = tmpdir.mkdir('error_pkg')
+    error_pkg.join('setup.py').write(
+        setup_header + error_commands + setup_footer)
+
+    with error_pkg.as_cwd():
+        with pytest.raises(SystemExit):
+            run_setup('setup.py', ['build'])
+
+        stdout, stderr = capsys.readouterr()
+        assert "RuntimeError" in stderr
+
+    # Test warning when using deprecated exclude parameter
+    warn_commands = dedent("""\
+        cmdclassd = register_commands(NAME, VERSION, RELEASE)
+        package_info = get_package_info(exclude=['test*'])
+
+    """)
+
+    warn_pkg = tmpdir.mkdir('warn_pkg')
+    warn_pkg.join('setup.py').write(
+        setup_header + warn_commands + setup_footer)
+
+    with warn_pkg.as_cwd():
+        run_setup('setup.py', ['build'])
+        stdout, stderr = capsys.readouterr()
+        assert 'AstropyDeprecationWarning' in stderr
